==> telephone-sqlserver-3.0.19.jar: filiale/tongchuan/sql/serviceDetails.sql <==
SELECT
    *
FROM
    (
        SELECT
            tswo.*,
            tsw.f_date,
            tsw.f_name,
            tsw.f_date_come,
            tsw.f_date_leave,
            tsw.f_signname,
            tsw.f_sign_imgid,
            tsw.f_result_status,
            tsw.f_service_idea,
            sa.defname,
            res2.callCount,
            sa.sender,
            cinsu.f_content,
            cptd.f_complaint_results,
            CASE
                WHEN tsw.f_result_status = '已完成'
                    OR f_success = '完成' THEN
                    0
                WHEN tswo.f_repairtype = '抢险' THEN
                    1 ELSE 0
                END repairtypeend,
            CASE
                WHEN res.degree = '1' THEN
                    '非常满意'
                WHEN res.degree = '2' THEN
                    '满意'
                WHEN res.degree = '3' THEN
                    '一般'
                WHEN res.degree = '4' THEN
                    '不满意'
                WHEN res.degree = '5' THEN
                    '非常不满意' ELSE '非常满意'
                END degrees --非常满意  1 满意 2 一般 3 不满意4 非常不满意5
        FROM
            t_serviceworkorder tswo
                LEFT JOIN ( SELECT * FROM t_servicework sw WHERE sw.id = ( SELECT MAX ( id ) FROM t_servicework WHERE serviceid = sw.serviceid ) ) tsw ON tswo.id = tsw.serviceid
                LEFT JOIN t_records res ON tswo.f_records_id = res.id
                LEFT JOIN ( SELECT COUNT ( 1 ) AS callCount, telnum FROM t_records WHERE starttime IS NOT NULL AND endtime IS NOT NULL GROUP BY telnum ) res2 ON tswo.f_phone = res2.telnum
                LEFT JOIN ( SELECT * FROM ACTIVITYINS act
                                      WHERE defname in ('站点接单', '维修员接单', '班组长派单', '维修完成','置换完成','安装完成','安装员接单','置换员接单','处理完成') and state='开始活动'
            ) SA ON tswo.F_PROCESSID = sa.PROCESSID
                LEFT JOIN ( SELECT f_content, f_service_id FROM t_complaint UNION ALL SELECT f_content, f_service_id FROM t_consult ) cinsu ON tswo.f_service_id = cinsu.f_service_id
                LEFT JOIN t_complanintend cptd ON cptd.serviceid = tswo.id
    ) t
WHERE
    {condition }
ORDER BY
    repairtypeend DESC,
    f_created_date DESC

==> telephone-sqlserver-3.0.68.jar: filiale/tongchuan/sql/serviceDetails.sql <==
SELECT
    *
FROM
    (
        SELECT
            tswo.*,
            tsw.f_date,
            tsw.f_name,
            tsw.f_date_come,
            tsw.f_date_leave,
            tsw.f_signname,
            tsw.f_sign_imgid,
            tsw.f_result_status,
            tsw.f_service_idea,
            sa.defname,
            res2.callCount,
            sa.sender,
            cinsu.f_content,
            cptd.f_complaint_results,
            CASE
                WHEN tsw.f_result_status = '已完成'
                    OR f_success = '完成' THEN
                    0
                WHEN tswo.f_repairtype = '抢险' THEN
                    1 ELSE 0
                END repairtypeend,
            CASE
                WHEN res.degree = '1' THEN
                    '非常满意'
                WHEN res.degree = '2' THEN
                    '满意'
                WHEN res.degree = '3' THEN
                    '一般'
                WHEN res.degree = '4' THEN
                    '不满意'
                WHEN res.degree = '5' THEN
                    '非常不满意' ELSE '非常满意'
                END degrees --非常满意  1 满意 2 一般 3 不满意4 非常不满意5
        FROM
            t_serviceworkorder tswo
                LEFT JOIN ( SELECT * FROM t_servicework sw WHERE sw.id = ( SELECT MAX ( id ) FROM t_servicework WHERE serviceid = sw.serviceid ) ) tsw ON tswo.id = tsw.serviceid
                LEFT JOIN t_records res ON tswo.f_records_id = res.id
                LEFT JOIN ( SELECT COUNT ( 1 ) AS callCount, telnum FROM t_records WHERE starttime IS NOT NULL AND endtime IS NOT NULL and telnum != '' GROUP BY telnum ) res2 ON tswo.f_phone = res2.telnum
                LEFT JOIN ( SELECT * FROM ACTIVITYINS act
                                      WHERE defname in ('话务员派单','站点接单', '维修员接单', '班组长派单', '维修完成','置换完成','安装完成','安装员接单','置换员接单','处理完成') and state='开始活动'
            ) SA ON tswo.F_PROCESSID = sa.PROCESSID
                LEFT JOIN ( SELECT f_content, f_service_id FROM t_complaint UNION ALL SELECT f_content, f_service_id FROM t_consult ) cinsu ON tswo.f_service_id = cinsu.f_service_id
                LEFT JOIN t_complanintend cptd ON cptd.serviceid = tswo.id
    ) t
WHERE
    {condition }
ORDER BY
    f_created_date DESC
